@@ -13,8 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
+
 import libvirt
-import mock
 
 from virtualbmc import exception
 from virtualbmc.tests.unit import base
